@@ -16,14 +16,20 @@ Most values of constants come from
 from . import (
     angle,
     area,
+    capacitance,
     charge,
     constants,
     current,
+    data,
     derived,
     energy,
     force,
     frequency,
+    inductance,
     length,
+    luminosity,
+    magneticflux,
+    magneticfluxdensity,
     mass,
     mole,
     power,
@@ -43,5 +49,3 @@ from ._api import (
     SIUNITX_OLD,
     SIUNITX_NEW,
 )
-
-from ._exceptions import UnitException, ImplicitConversionError, OperationError
