@@ -4,7 +4,7 @@ import re
 import textwrap
 import warnings
 from decimal import Decimal
-from typing import Union, Tuple, Sequence, Type, Dict, Iterator, Optional
+from typing import Union, Tuple, Type, Dict, Iterator, Optional
 
 import sigfig
 
@@ -20,7 +20,7 @@ __all__ = [
     "SIUNITX_OLD",
 ]
 UnitOperand = Union['UnitInterface', int, float, Decimal]
-Scale = Union[Decimal, float, str, Tuple[int, Sequence[int], int]]
+Scale = Union[Decimal, float, str]
 Unitlike = Union[Type['UnitInterface'], 'DimensionBase']
 Pair = Tuple[Unitlike, int]
 Pairs = Tuple[Pair, ...]
@@ -281,9 +281,26 @@ def _access_unit_cache(c: 'Compound', scale) -> Optional[Type['UnitBase']]:
     key = (_sort(_dedupe(c.to_pairs())), scale)
     if key in remap:
         return remap[key]
+    if len(c) == 1 and _is_base(c):
+        # Particular case: SI derivatives of base units are also base units,
+        # divorced from their root
+        magnitude = scale.log10()
+        if magnitude == int(magnitude):
+            si_prefix = [prefix for prefix, _, sc in _SI_PREFIXES if Decimal(sc) == scale]
+            if len(si_prefix) != 1:
+                return None
+            si_name = si_prefix[0] + c.to_pairs()[0][0].__name__
+            if si_name in _EXTANT_UNITS:
+                return _EXTANT_UNITS[si_name]
     return None
 
 
+def _is_base(composition: 'Compound') -> bool:
+    return (len(composition) == 1
+            and composition.to_pairs()[0][1] == 1
+            and composition.to_pairs()[0][0].composition == composition)
+
+
 def _base_scale(composition: Union['Compound', Pairs]) -> Decimal:
     base_scale = Decimal(1)
     for u, e in composition:
