@@ -3,19 +3,12 @@ from pyunitx.length import Length, meters
 
 __all__ = [
     "Area",
-    "meters_squared",
     "acres",
     "hectares",
 ]
 
 Area = make_compound_dimension(name="Area", exponents={Length: 2})
 
-# no need to explain square meters
-meters_squared = make_compound_unit(
-    exponents={meters: 2},
-    scale=1
-)
-
 acres = make_compound_unit(
     name="acres",
     abbrev="acre",
