@@ -13,10 +13,7 @@ meters = make_unit(
     """
 )
 
-generated = si_unit(
-    base_unit=meters,
-    short_doc="""The base unit is :class:`pyunitx.length.meters`."""
-)
+generated = si_unit(base_unit=meters)
 globals().update(generated)
 
 feet = make_unit(
@@ -55,17 +52,18 @@ astronomical_unit = au = make_unit(
     doc="""\
     One astronomical unit, or AU, is the average distance between Earth and the
     Sun. It's used in astronomical measurements, and is part of the definition
-    of the :class:`parsec <pyunitx.derived.parsec>`.
+    of the :class:`parsecs <pyunitx.derived.parsecs>`.
     """
 )
 
 __all__ = [
-              "Length",
-              "meters",
-              "feet",
-              "miles",
-              "yards",
-              "inches",
-              "astronomical_unit",
-              "au",
-          ] + list(generated.keys())
+    "Length",
+    "meters",
+    "feet",
+    "miles",
+    "yards",
+    "inches",
+    "astronomical_unit",
+    "au",
+    *generated.keys()
+]
